#
# Copyright (C) 2013-2013, Intercom Srl, Daniele Orlandi
#
# Author:: Daniele Orlandi <daniele@orlandi.com>
#          Lele Forzani <lele@windmill.it>
#          Alfredo Cerutti <acerutti@intercom.it>
#
# License:: You can redistribute it and/or modify it under the terms of the LICENSE file.
#

require 'ygg/provisioner/file_switcher'

module Ygg
module Provisioner

class ColonDelimitedFile
  include FileSwitcher

  def initialize(filename, opts = {})
    @entries = {}
    @tmp_filename = opts[:tmpname] || filename + '.new'

    File::open(filename, 'r') do |f|
      f.each_line do |line|
        line.chomp!
        entry = line.split(':', opts[:limit] || -1)

        @entries[entry[0]] = entry
      end
    end rescue Errno::ENOENT

    yield self

    File::open(@tmp_filename, 'w') do |f|
      @entries.each do |entrykey, entry|
        f << entry.join(':') + "\n"
      end
    end

    uid = opts[:uid]
    gid = opts[:gid]
    begin
      uid = File.stat(filename).uid
      gid = File.stat(filename).gid
    rescue Errno::ENOENT
    end

    FileUtils::chown(uid, gid, @tmp_filename)

    switch_files(@tmp_filename, filename)
  end

  def set(data)
    @entries[data[0]] = data
  end

  def [](key)
    @entries[key]
  end

  def delete(key)
    @entries.delete(key)
  end
end

end
end
