#
# Copyright (C) 2013-2013, Intercom Srl, Daniele Orlandi
#
# Author:: Daniele Orlandi <daniele@orlandi.com>
#          Lele Forzani <lele@windmill.it>
#          Alfredo Cerutti <acerutti@intercom.it>
#
# License:: You can redistribute it and/or modify it under the terms of the LICENSE file.
#

require 'ygg/provisioner/colon_delimited_file'

module Ygg
module Provisioner

module SystemDb
  PASSWD_FILE = '/etc/passwd'
  SHADOW_FILE = '/etc/shadow'
  GROUP_FILE = '/etc/group'

  def self.update_passwd(accounts)
    ColonDelimitedFile.new(PASSWD_FILE, :tmpname => PASSWD_FILE + '.provisioner.tmp') do |cdf|
      accounts.each do |account|

        cdf.set([
          account[:username],    # username
          'x',
          account[:uid],  # uid
          account[:gid],  # gid
          '',             # gecos
          account[:dir],  # homedir
          '/bin/false',   # shell
        ])
      end
    end
  end

  def self.update_shadow(accounts)
    ColonDelimitedFile.new(SHADOW_FILE, :tmpname => SHADOW_FILE + '.provisioner.tmp') do |cdf|
      accounts.each do |account|
        cdf.set([
          account[:username],    # username
          Password.new(account[:password]).crypt_with_random_salt(6),
          '14593',        #
          '0',            #
          '99999',        #
          '7',            #
          '',             #
          '',             #
          '',             #
        ])
      end
    end
  end

  def self.update_group(group, accounts)
    ColonDelimitedFile.new(GROUP_FILE, :tmpname => GROUP_FILE + '.provisioner.tmp') do |cdf|
      raise "Missing group #{group}" if !cdf[group]

      accs = cdf[group][3].split(',')
      accs += accounts.map { |x| x[:username] }

      cdf[group][3] = accs.sort.uniq.join(',')
    end
  end
end

end
end
